"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MongoIdParamFactory = MongoIdParamFactory;
const common_1 = require("@nestjs/common");
const class_validator_1 = require("class-validator");
/**
 * Returns parameter decorator which validates if given value is Mongo ID.
 */
function MongoIdParamFactory(badRequestFactory) {
    class MongoIdValidationPipe {
        transform(value) {
            if (!(0, class_validator_1.isMongoId)(value)) {
                if (badRequestFactory) {
                    throw badRequestFactory(value);
                }
                throw new common_1.BadRequestException(`'${value}' is not a valid Mongo ID`);
            }
            return value;
        }
    }
    return function MongoIdParam(property) {
        return (0, common_1.Param)(property, MongoIdValidationPipe);
    };
}
