import { QueryData, QueryResult } from '@jchpro/nest-common';
import type { Document, FilterQuery, Model, ProjectionType, Query, QueryOptions } from 'mongoose';
import { CrudOptions, FilterQueryProvider } from '../types/crud';
/**
 * Holds the query data for a given mongoose model and allows
 * execution of `count`, `find`, or both using `execute`.
 */
export declare class QueryExecutor<TDoc extends Document, TRaw = any> {
    readonly model: Model<TDoc>;
    readonly data: QueryData;
    readonly maxLimit?: number;
    readonly filters: FilterQuery<TRaw>;
    readonly queryOptions: QueryOptions<TDoc>;
    readonly projection?: ProjectionType<TRaw>;
    constructor(model: Model<TDoc>, data: QueryData, options?: {
        readonly filtersProvider?: FilterQueryProvider<TRaw>;
        readonly project?: ProjectionType<TRaw>;
        readonly crud?: CrudOptions;
        readonly other?: OtherQueryOptions;
    });
    execute(count?: Query<number, TDoc>, find?: Query<TDoc[], TDoc>): Promise<QueryResult<TDoc>>;
    count(): Query<number, TDoc>;
    find(): Query<TDoc[], TDoc>;
    private resolveQueryOptions;
}
export type OtherQueryOptions = Omit<QueryOptions, 'skip' | 'limit' | 'sort'>;
