"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueryExecutor = void 0;
const nest_common_1 = require("@jchpro/nest-common");
/**
 * Holds the query data for a given mongoose model and allows
 * execution of `count`, `find`, or both using `execute`.
 */
class QueryExecutor {
    constructor(model, data, options) {
        this.model = model;
        this.data = data;
        const { maxLimit } = options?.crud ?? {};
        this.maxLimit = maxLimit;
        this.projection = options?.project;
        this.filters = options?.filtersProvider?.getFilters() ?? {};
        this.queryOptions = this.resolveQueryOptions(options?.other);
    }
    async execute(count, find) {
        const countQuery = count ?? this.count();
        const findQuery = find ?? this.find();
        const [total, items] = await Promise.all([countQuery.exec(), findQuery.exec()]);
        return new nest_common_1.QueryResult(items, total, this.queryOptions.limit, this.queryOptions.skip);
    }
    count() {
        return this.model.countDocuments(this.filters);
    }
    find() {
        return this.model.find(this.filters, this.projection, this.queryOptions);
    }
    resolveQueryOptions(other) {
        const { offset, limit, sortBy, sortDesc } = this.data;
        const queryOptions = { ...other };
        if (typeof offset === 'number') {
            queryOptions.skip = offset;
        }
        if (typeof limit === 'number') {
            if (limit > (this.maxLimit ?? Infinity)) {
                queryOptions.limit = this.maxLimit;
            }
            else {
                queryOptions.limit = limit;
            }
        }
        if (typeof sortBy === 'string') {
            queryOptions.sort = {
                [sortBy]: sortDesc ? -1 : 1
            };
        }
        return queryOptions;
    }
}
exports.QueryExecutor = QueryExecutor;
